<h1>Features
</h1>

### Attaching a block to an entity

You can quickly attach a block to an entity. This allows to use the CMS editing capabilities of the plugin to manage the content associated to a given entity. 

For example, you can attach a CMS Block to a Taxon and display the block on the Taxon Page. 

#### Make the entity BlockAware

Implement your interface

    ```php
    <?php
    
    declare(strict_types=1);

    namespace App\Entity;

    use Dedi\SyliusCmsPlugin\Entity\BlockAwareInterface;
    use Sylius\Component\Core\Model\TaxonInterface as BaseTaxonInterface;
    
    interface TaxonInterface extends BaseTaxonInterface, BlockAwareInterface
    ```

Implement your entity
    
    ```php
    <?php
    
    declare(strict_types=1);

    namespace App\Entity;
    
    use Dedi\SyliusCmsPlugin\Entity\BlockAwareTrait;
    use Sylius\Component\Core\Model\Taxon as BaseTaxon;
    
    class Taxon extends BaseTaxon implements TaxonInterface
    {
        use BlockAwareTrait;
    
        public function getBlockCodePrefix(): string
        {
            return 'TAXON';
        }
    }
    ```
    
Don't forget to tell Sylius to use your new entities

```yaml
# config/packages/_sylius.yaml
sylius_taxonomy:
    resources:
        taxon:
            classes:
                model: App\Entity\Taxon
                interface: App\Entity\TaxonInterface
```

    
Note : the `getBlockCodePrefix` function is used to generate the code for the associated Block (see `BlockAwareTrait::generateBlockCode`). The code follows the pattern `[codePrefix]_[entityCode]`. This means that your entity should be `CodeAware` as defined in the `BlockAwareInterface`

### Update your database 

```bash
$ bin/console doctrine:migrations:diff
$ bin/console doctrine:migrations:migrate
```

### Add the block management section to the entity form

Define a type extension for your entity's form and use the `BlockAwareTraitType` to add the block admin. 

    ```php
    <?php
    
    declare(strict_types=1);
    
    namespace App\Form\Extension;
    
    use Dedi\SyliusCmsPlugin\Form\Type\BlockAwareType;
    use Sylius\Bundle\TaxonomyBundle\Form\Type\TaxonType;
    use Symfony\Component\Form\AbstractTypeExtension;
    use Symfony\Component\Form\FormBuilderInterface;
    
    class TaxonTypeExtension extends AbstractTypeExtension
    {
        use BlockAwareTraitType;

        public function buildForm(FormBuilderInterface $builder, array $options): void
        {
            ... 
            
            $this->buildBlockAwareForm($builder, $options);    
            
            ...
        }
    
        public static function getExtendedTypes(): iterable
        {
            return [TaxonType::class];
        }
    }
    ```
This trait adds a block field and an event listener to update the block code based on the associated entity's code. 
    
### Render the block management section

Use the form_theme provided by the plugin and display the new field as a row

```twig
{# templates/bundles/SyliusAdminBundle/Taxon/_form.html.twig #}

...

{% form_theme form '@DediSyliusCmsPlugin/Admin/BlockAware/Form/theme.html.twig' %}

{{ form_row(form.block) }}

...

```

### Render the content

```twig
    {{ bitbag_cms_render_block(taxon.block.code) }}
```
